package hideandseek.managers;

import org.bukkit.ChatColor;
import org.bukkit.plugin.Plugin;
import org.bukkit.scheduler.BukkitRunnable;
import hideandseek.HideAndSeek;
import org.bukkit.command.CommandSender;
import org.bukkit.Bukkit;
import java.util.Collection;
import org.bukkit.entity.Player;
import hideandseek.utils.ItemStackBuilder;
import hideandseek.PlayerData;
import java.util.Iterator;
import org.bukkit.configuration.file.FileConfiguration;
import java.util.Collections;
import hideandseek.utils.Utils;
import java.util.List;
import org.bukkit.inventory.ItemStack;
import java.util.ArrayList;
import java.util.HashMap;
import hideandseek.utils.FlexibleSmartInventory;

public class AchievementsManager
{
    private static AchievementsManager instance;
    FlexibleSmartInventory original;
    private final HashMap<AchievementType, ArrayList<Achievement>> achievements;
    private String guiTitle;
    private ItemStack lockedAchievementItem;
    private ItemStack unlockedAchievementItem;
    private String lockedAchievementName;
    private String unlockedAchievementName;
    private List<String> lockedAchievementLore;
    private List<String> unlockedAchievementLore;
    private ArrayList<String> unlockMessages;
    
    public AchievementsManager() {
        this.achievements = new HashMap<AchievementType, ArrayList<Achievement>>();
        AchievementsManager.instance = this;
        final FileConfiguration var1 = FilesManager.getInstance().getConfig("achievements.yml");
        if (var1.getBoolean("Enabled")) {
            this.guiTitle = Utils.colorize(var1.getString("GUI.Title"));
            this.lockedAchievementItem = Utils.getItemStack(var1.getString("GUI.Locked-Achievement-Item.Item"), false, true);
            this.lockedAchievementName = Utils.colorize(var1.getString("GUI.Locked-Achievement-Item.Name"));
            this.lockedAchievementLore = new ArrayList<String>();
            for (final String var3 : var1.getStringList("GUI.Locked-Achievement-Item.Lore")) {
                this.lockedAchievementLore.add(Utils.colorize(var3));
            }
            this.unlockedAchievementItem = Utils.getItemStack(var1.getString("GUI.Unlocked-Achievement-Item.Item"), false, true);
            this.unlockedAchievementName = Utils.colorize(var1.getString("GUI.Unlocked-Achievement-Item.Name"));
            this.unlockedAchievementLore = new ArrayList<String>();
            for (final String var3 : var1.getStringList("GUI.Unlocked-Achievement-Item.Lore")) {
                this.unlockedAchievementLore.add(Utils.colorize(var3));
            }
            this.unlockMessages = new ArrayList<String>();
            for (final String var3 : var1.getStringList("Unlock-Message")) {
                this.unlockMessages.add(Utils.colorize(var3));
            }
            AchievementType[] var4 = AchievementType.values();
            for (int var5 = var4.length, var6 = 0; var6 < var5; ++var6) {
                final AchievementType var7 = var4[var6];
                if (!var1.contains("Achievements." + var7.name().toLowerCase())) {
                    final int[] var8 = var7.levels;
                    for (int var9 = var8.length, var10 = 0; var10 < var9; ++var10) {
                        final int var11 = var8[var10];
                        final String var12 = "Achievements." + var7.name().toLowerCase() + "." + var11;
                        var1.set(var12 + "name", (Object)var7.name);
                        var1.set(var12 + "description", (Object)var7.defaultDescription.replace("%x%", String.valueOf(var11)));
                        var1.set(var12 + "prize-description", "赚取 " + (int)(var7.prizeMultiplier * var11) + " 枚游戏币!");
                        var1.set(var12 + "executed-command", (Object)Collections.singletonList("hideandseek coins add %player% " + (int)(var7.prizeMultiplier * var11)));
                    }
                }
            }
            FilesManager.getInstance().saveConfig("achievements.yml");
            var4 = AchievementType.values();
            for (int var5 = var4.length, var6 = 0; var6 < var5; ++var6) {
                final AchievementType var7 = var4[var6];
                String var13 = "Achievements." + var7.name().toLowerCase();
                final ArrayList var14 = new ArrayList();
                if (!var1.getConfigurationSection(var13).getKeys(false).isEmpty()) {
                    for (String var16 : var1.getConfigurationSection(var13).getKeys(false)) {
                        var13 = "Achievements." + var7.name().toLowerCase() + "." + var16;
                        final String var12 = var1.getString(var13 + "name");
                        final String var17 = var1.getString(var13 + "description");
                        final String var18 = var1.getString(var13 + "prize-description");
                        final List var19 = var1.getStringList(var13 + "executed-command");
                        var14.add(new Achievement(Integer.parseInt(var16), var12, var17, var18, var19));
                    }
                }
                this.achievements.put(var7, var14);
            }
            final List var20 = this.getAllAchievements();
            (this.original = new FlexibleSmartInventory(this.guiTitle)).addInventory("", var20.size(), (HashMap)null);
            final ArrayList var21 = this.original.prepareForItems(0, var20.size());
            int var6 = 0;
            for (final Achievement var23 : var20) {
                final FlexibleSmartInventory.PositionData var24 = var21.get(var6);
                var23.id = var24.id;
                var23.subId = var24.subId;
                var23.slot = var24.slot;
                ++var6;
            }
        }
    }
    
    public static AchievementsManager getInstance() {
        return AchievementsManager.instance;
    }
    
    public FlexibleSmartInventory getAchievementsInventory(final PlayerData var1) {
        if (!this.isEnabled()) {
            return null;
        }
        final int[] var2 = { var1.seekersKilled, var1.hidersKilled, var1.gamesPlayed, var1.wins, var1.perks.size() };
        if (var2.length != AchievementType.values().length) {
            return null;
        }
        final FlexibleSmartInventory var3 = this.original.clone();
        for (final AchievementType var7 : AchievementType.values()) {
            final int var8 = var2[var7.ordinal()];
            for (final Achievement var10 : this.achievements.get(var7)) {
                final boolean var11 = var8 >= var10.score;
                final ItemStackBuilder var12 = new ItemStackBuilder(var11 ? this.unlockedAchievementItem.clone() : this.lockedAchievementItem.clone());
                var12.setName(var11 ? this.unlockedAchievementName.replace("%achievement_name%", var10.name).replace("description", var10.description).replace("%prize_description%", var10.prizeDescription) : this.lockedAchievementName.replace("%achievement_name%", var10.name).replace("description", var10.description).replace("%prize_description%", var10.prizeDescription));
                for (final String var14 : var11 ? this.unlockedAchievementLore : this.lockedAchievementLore) {
                    var12.addLore(new String[] { var14.replace("%achievement_name%", var10.name).replace("%description%", var10.description).replace("%prize_description%", var10.prizeDescription) });
                }
                var3.setItem(var10.id, var10.subId, var10.slot, var12.build());
            }
        }
        return var3;
    }
    
    public boolean isEnabled() {
        return !this.achievements.isEmpty();
    }
    
    public String getGuiTitle() {
        return this.guiTitle;
    }
    
    public void checkPlayer(final Player var1, final AchievementType var2, final int var3) {
        if (this.isEnabled()) {
            for (final Achievement var5 : this.achievements.get(var2)) {
                if (var3 == var5.score) {
                    var5.send(var1);
                    break;
                }
            }
        }
    }
    
    private List<Achievement> getAllAchievements() {
        final ArrayList var1 = new ArrayList();
        for (final AchievementType var5 : AchievementType.values()) {
            var1.addAll(this.achievements.get(var5));
        }
        return var1;
    }
    
    public int getSize() {
        return this.getAllAchievements().size();
    }
    
    public enum AchievementType
    {
        SEEKERS_KILLED("SEEKERS_KILLED", 0, "谁才是抓捕者？", "淘汰%x%个抓捕者", 10.0, new int[] { 10, 50, 100, 200, 500 }), 
        HIDERS_KILLED("HIDERS_KILLED", 1, "方块屠夫", "干掉%x%个躲藏者", 5.0, new int[] { 10, 50, 100, 200, 500 }), 
        GAMES_PLAYED("GAMES_PLAYED", 2, "玩过的游戏", "玩过%x%场游戏!", 10.0, new int[] { 1, 5, 20, 50, 100, 200, 500 }), 
        WINS("WINS", 3, "赢家", "赢了%x%场游戏!", 10.0, new int[] { 1, 10, 50, 100, 200 }), 
        PERKS_PURCHASED("PERKS_PURCHASED", 4, "技能大师", "购买%x%次小技能!", 100.0, new int[] { 1, 3, 6 });
        
        public String name;
        public String defaultDescription;
        public double prizeMultiplier;
        public int[] levels;
        
        private AchievementType(final String name, final int ordinal, final String var3, final String var4, final double var5, final int... var7) {
            this.name = var3;
            this.defaultDescription = var4;
            this.prizeMultiplier = var5;
            this.levels = var7;
        }
    }
    
    public class Achievement
    {
        int score;
        String name;
        String description;
        String prizeDescription;
        List<String> executedCommands;
        int id;
        int subId;
        int slot;
        
        public Achievement(final int var2, final String var3, final String var4, final String var5, final List<String> var6) {
            this.score = var2;
            this.name = var3;
            this.description = var4;
            this.prizeDescription = var5;
            this.executedCommands = var6;
        }
        
        public void send(final Player var1) {
            for (final String var3 : this.executedCommands) {
                Bukkit.dispatchCommand((CommandSender)Bukkit.getConsoleSender(), var3.replace("%player%", var1.getName()));
            }
            final ChatColor var4 = Utils.getGoodColor();
            for (final String var6 : AchievementsManager.this.unlockMessages) {
                var1.sendMessage(var6.replace("%randomcolor%", var4.toString()).replace("%achievement_name%", this.name).replace("%description%", this.description).replace("%prize_description%", this.prizeDescription));
            }
            if (HideAndSeek.getInstance().achievement_unlock_title != null) {
                TitleManager.getInstance().sendTitle(var1, HideAndSeek.getInstance().achievement_unlock_title);
            }
            Utils.playSound(var1, "Achievement-Unlock");
            new BukkitRunnable() {
                int x = 0;
                
                public void run() {
                    if (this.x == 7) {
                        this.cancel();
                    }
                    Utils.playSound(var1, "Achievement-Celebration");
                    ++this.x;
                }
            }.runTaskTimer((Plugin)HideAndSeek.getInstance(), 5L, 5L);
        }
    }
}
